%global srcname trove

Summary:          OpenStack DBaaS (%{srcname})
Name:             openstack-%{srcname}
Version:          18.0.0
Release:          2%{?dist}
License:          ASL 2.0
URL:              https://wiki.openstack.org/wiki/Trove
Source0:          https://tarballs.openstack.org/%{srcname}/%{srcname}-%{version}.tar.gz
Source1:          %{srcname}.logrotate
Source2:          guest_info
Source3:          %{name}-api.service
Source4:          %{name}-taskmanager.service
Source5:          %{name}-conductor.service
Source6:          %{name}-guestagent.service

Patch0001:        0001-Fix-inspect.getargspec-deprecation-warning.patch

BuildArch:        noarch

BuildRequires: python3-osprofiler
BuildRequires: python3-oslo-log python3-oslo-messaging python3-oslo-middleware python3-oslo-policy
BuildRequires: python3-keystoneauth1 python3-keystonemiddleware python3-oslo-config
BuildRequires: python3-d2to1 python3-sphinx crudini intltool
BuildRequires: python3-devel python3-setuptools python3-pbr

Requires:         %{name}-api = %{version}-%{release}
Requires:         %{name}-taskmanager = %{version}-%{release}
Requires:         %{name}-conductor = %{version}-%{release}


%description
Trove is Database as a Service for OpenStack. It's designed to run entirely on OpenStack, with the goal of allowing users to quickly and easily utilize the features of a relational or non-relational database without the burden of handling complex administrative tasks. Cloud users and database administrators can provision and manage multiple database instances as needed. Initially, the service will focus on providing resource isolation at high performance while automating complex administrative tasks including deployment, configuration, patching, backups, restores, and monitoring.

%package common
Summary:          Components common to all OpenStack %{srcname} services
BuildRequires:    systemd
Requires:         python3-%{srcname} = %{version}-%{release}
%{?systemd_requires}
Requires(pre):    shadow-utils
Requires:         python3-pbr

%description common
This package contains scripts, config and dependencies shared
between all the OpenStack %{srcname} services.


%package api
Summary:          OpenStack %{srcname} API service
Requires:         %{name}-common = %{version}-%{release}

%description api
This package contains the %{srcname} interface daemon.


%package taskmanager
Summary:          OpenStack %{srcname} taskmanager service
Requires:         %{name}-common = %{version}-%{release}

%description taskmanager
This package contains the %{srcname} taskmanager service.


%package conductor
Summary:          OpenStack %{srcname} conductor service
Requires:         %{name}-common = %{version}-%{release}

%description conductor
This package contains the %{srcname} conductor service.


%package guestagent
Summary:          OpenStack %{srcname} guest agent
Requires:         python3-pexpect
Requires:         %{name}-common = %{version}-%{release}

%description guestagent
This package contains the %{srcname} guest agent service
that runs within the database VM instance.


%package -n       python3-%{srcname}
Summary:          Python libraries for %{srcname}
Requires: python3-jsonschema python3-babel python3-jinja2 python3-httplib2 python3-passlib
Requires: python3-oslo-middleware python3-oslo-policy python3-oslo-serialization python3-oslo-service python3-oslo-utils python3-osprofiler
Requires: python3-oslo-config python3-oslo-context python3-oslo-db python3-oslo-i18n python3-oslo-log python3-oslo-messaging
Requires: python3-keystoneclient python3-keystonemiddleware python3-neutronclient python3-novaclient python3-swiftclient python3-oslo-concurrency
Requires: python3-routes python3-troveclient python3-cinderclient python3-designateclient python3-glanceclient python3-heatclient
Requires: python3-stevedore python3-xmltodict python3-webob python3-sqlalchemy python3-paste python3-paste-deploy
Requires: python3-eventlet python3-iso8601 python3-netaddr python3-lxml python3-six python3-PyMySQL python3-kombu python3-cryptography

%description -n   python3-%{srcname}
This package contains the %{srcname} python library.

%package -n python3-%{srcname}-tests
Summary:        Trove tests
Requires:       python3-%{srcname} = %{version}-%{release}

%description -n python3-%{srcname}-tests
This package contains the Trove test files

%prep
%autosetup -n %{srcname}-%{version} -p1

find %{srcname} -name \*.py |
while read source; do
  if head -n1 "$source" | grep -F '/usr/bin/env'; then
    touch --ref="$source" "$source".ts
    sed -i '/\/usr\/bin\/env python/{d;q}' "$source"
    touch --ref="$source".ts "$source"
    rm "$source".ts
  fi
done

rm -rf *requirements.txt

%build
%py3_build

%install
%py3_install


export PYTHONPATH=$PYTHONPATH:.
oslo-config-generator --namespace trove.config --namespace oslo.messaging --namespace oslo.log --namespace oslo.log --namespace oslo.policy --output-file etc/%{srcname}/%{srcname}.conf.sample

install -d -m 755 %{buildroot}%{_unitdir}
install -d -m 755 %{buildroot}%{_datadir}/%{srcname}
install -d -m 755 %{buildroot}%{_sharedstatedir}/%{srcname}
install -d -m 750 %{buildroot}%{_localstatedir}/log/%{srcname}

install -p -D -m 640 etc/apache2/%{srcname} %{buildroot}%{_sysconfdir}/apache2/%{srcname}
install -p -D -m 640 etc/%{srcname}/%{srcname}.conf.sample %{buildroot}%{_sysconfdir}/%{srcname}/%{srcname}.conf
crudini --set %{buildroot}%{_sysconfdir}/%{srcname}/%{srcname}.conf database connection mysql://trove:trove@localhost/trove
crudini --set %{buildroot}%{_sysconfdir}/%{srcname}/%{srcname}.conf DEFAULT log_file %{_localstatedir}/log/%{srcname}/%{srcname}.log
mv %{buildroot}%{_prefix}/etc/%{srcname}/api-paste.ini %{buildroot}%{_sysconfdir}/%{srcname}/api-paste.ini
rmdir %{buildroot}%{_prefix}/etc/%{srcname}
install -d -m 755 %{buildroot}%{_sysconfdir}/%{srcname}
install -p -D -m 640 etc/%{srcname}/%{srcname}.conf.sample %{buildroot}%{_sysconfdir}/%{srcname}/trove-taskmanager.conf
install -p -D -m 640 etc/%{srcname}/%{srcname}.conf.sample %{buildroot}%{_sysconfdir}/%{srcname}/trove-conductor.conf
install -p -D -m 640 etc/%{srcname}/%{srcname}.conf.sample %{buildroot}%{_sysconfdir}/%{srcname}/trove-guestagent.conf
install -p -D -m 640 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{srcname}/guest_info
install -p -m 644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/run/%{srcname}

rm -fr %{buildroot}%{_bindir}/trove-fake-mode
rm -fr %{buildroot}%{python3_sitelib}/run_tests.*

%pre common
USERNAME=%{srcname}
GROUPNAME=$USERNAME
HOMEDIR=%{_sharedstatedir}/$USERNAME
getent group $GROUPNAME >/dev/null || groupadd -r $GROUPNAME
getent passwd $USERNAME >/dev/null || \
  useradd -r -g $GROUPNAME -G $GROUPNAME -d $HOMEDIR -s /sbin/nologin \
    -c "$USERNAME Daemons" $USERNAME
exit 0

%post api
%systemd_post openstack-trove-api.service
%post taskmanager
%systemd_post openstack-trove-taskmanager.service
%post conductor
%systemd_post openstack-trove-conductor.service
%post guestagent
%systemd_post openstack-trove-guestagent.service

%preun api
%systemd_preun openstack-trove-api.service
%preun taskmanager
%systemd_preun openstack-trove-taskmanager.service
%preun conductor
%systemd_preun openstack-trove-conductor.service
%preun guestagent
%systemd_preun openstack-trove-guestagent.service

%postun api
%systemd_postun_with_restart openstack-trove-api.service
%postun taskmanager
%systemd_postun_with_restart openstack-trove-taskmanager.service
%postun conductor
%systemd_postun_with_restart openstack-trove-conductor.service
%postun guestagent
%systemd_postun_with_restart openstack-trove-guestagent.service


%files
%license LICENSE

%files common
%license LICENSE
%{_bindir}/%{srcname}-manage
%{_bindir}/%{srcname}-status
%{_bindir}/%{srcname}-wsgi
%{_bindir}/trove-mgmt-taskmanager
%dir %{_sysconfdir}/%{srcname}
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/%{srcname}.conf
%attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/api-paste.ini
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(0750, %{srcname}, root) %{_localstatedir}/log/%{srcname}
%dir %attr(0755, %{srcname}, root) %{_localstatedir}/run/%{srcname}
%{_datarootdir}/%{srcname}
%defattr(-, %{srcname}, %{srcname}, -)
%dir %{_sharedstatedir}/%{srcname}

%files api
%{_bindir}/%{srcname}-api
%{_unitdir}/%{name}-api.service
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/apache2/%{srcname}

%files taskmanager
%{_bindir}/%{srcname}-taskmanager
%{_unitdir}/%{name}-taskmanager.service
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/%{srcname}-taskmanager.conf

%files conductor
%{_bindir}/%{srcname}-conductor
%{_unitdir}/%{name}-conductor.service
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/%{srcname}-conductor.conf

%files guestagent
%{_bindir}/%{srcname}-guestagent
%{_unitdir}/%{name}-guestagent.service
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/%{srcname}-guestagent.conf
%config(noreplace) %attr(0640, root, %{srcname}) %{_sysconfdir}/%{srcname}/guest_info

%files -n python3-%{srcname}
%license LICENSE
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}*.egg-info
%exclude %{python3_sitelib}/%{srcname}/tests

%files -n python3-%{srcname}-tests
%license LICENSE
%{python3_sitelib}/%{srcname}/tests

%changelog
* Fri Oct 13 2023 Shuo Wang <abushwang@tencent.com> - 18.0.0-2
- backport "Fix inspect.getargspec() deprecation warning"

* Sat Oct 7 2023 Shuo Wang <abushwang@tencent.com> - 18.0.0-1
- update to 18.0.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.0.0-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.0.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.0.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 14 2023 cunshunxia <cunshunxia@tencent.com> - 15.0.0-1
- initial build
